# All except winning bid disqualified (R035)

Bids are disqualified if not submitted by the single tenderer of the winning bid.

:::{seealso}
{doc}`038`
:::

## Methodology

A contracting process is flagged if:

- Exactly one tenderer submitted one or more bids that are valid (i.e. qualified).
- The tenderer of the valid bids and the suppliers of all active awards are the same.
- At least 1 other tenderer submitted a bid that was disqualified. (1 is the **threshold**.)

The winner is also flagged.

:::{admonition} Example
:class: seealso

The National Rail Service receives five bids. It disqualifies four bids, and awards the contract to the remaining bid from CorruptX Solutions.
:::

:::{admonition} Why is this a red flag?
:class: hint

A corrupt buyer can award the pre-determined bidder by disqualifying other bidders' bids.
:::

<small>Based on "Exclusion of all but one bid" in [*An Objective Corruption Risk Index Using Public Procurement Data*](https://www.researchgate.net/publication/301646354_An_Objective_Corruption_Risk_Index_Using_Public_Procurement_Data) and "Prevalence of faulty bids" in [*Toolkit for detecting collusive bidding in public procurement*](https://www.govtransparency.eu/wp-content/uploads/2015/11/GTI_WP2014_2_Toth_et_al_150413.pdf).</small>

## Output

The indicator's value for the contracting process is the number of unique tenderers with disqualified bids.

The indicator's value for the tenderer is always 0.0.

If the ``--map`` command-line flag is set, the ``Maps`` key contains:

ocid_tenderer_r035
: The flagged tenderers for each flagged `ocid`.

## Configuration

All configuration is optional. If you observe many false positives among contracting processes with few submitted bids, you can increase the threshold. To override the default **threshold**, add to your settings file, as a natural number:

```ini
[R035]
threshold = 1 # default
```

## Exclusions

A contracting process is excluded if:

- An award's status is pending or invalid.

## Demonstration

*Input*

:::{literalinclude} ../../../examples/R/035.jsonl
:language: json
:::

*Output*

```console
$ ocdscardinal indicators --settings docs/examples/R/035.ini --no-meta docs/examples/R/035.jsonl
{"OCID":{"F":{"R035":1.0}},"Tenderer":{"V":{"R035":0.0}}}

```
